@@ -11,7 +11,7 @@ use Regex::Object::Matches;
 use Moo;
 use namespace::clean;
 
-our $VERSION = '1.20';
+our $VERSION = '1.21';
 
 tie my %nc,  "Tie::Hash::NamedCapture";
 tie my %nca, "Tie::Hash::NamedCapture", all => 1;
@@ -84,7 +84,7 @@ Regex::Object - solves problems with global Regex variables side effects.
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 SYNOPSIS
 
@@ -131,14 +131,14 @@ version 1.20
     ######## ---- ########
     # Global search for scoped regex without while loop
 
-    $re = Regex::Object->new(regex  => qr/([A-Z]+?) ([A-Z]+)/i);
+    my $re      = Regex::Object->new(regex  => qr/([A-Z]+?) ([A-Z]+)/i);
     my $matches = $re->match_all('John Doe Eric Lide Hans Zimmermann');
 
     print join "\040", $matches->match_all; # prints John Doe Eric Lide Hans Zimmermann
 
 =head1 DESCRIPTION
 
-This module was created for one certain goal: give you a level
+This module was created for one certain goal: give developer a level
 of isolation from perlre global variables.
 
 The Regex::Object supports two approaches:
@@ -252,19 +252,19 @@ Returns hash ref of the named captures all.
 
 =head3 collection()
 
-Returns array ref with all Regex::Object::Match objects
+Returns array ref with all Regex::Object::Match objects.
 
     my $first_match = $matches->collection->[0];
 
 =head3 match_all()
 
-Return array ref with all matches, i.e $MATCH[]
+Return array ref with all matches, i.e $MATCH[].
 
     my $match_all_array_ref = $matches->match_all;
 
 =head3 captures_all()
 
-Return array ref with all captures
+Return array ref with all captures.
 
     my $captures_all_array_ref = $matches->captures_all;
 
